=== modified file 'NEWS'
--- NEWS	2008-06-06 18:04:45 +0000
+++ NEWS	2008-05-04 20:23:56 +0000
@@ -1,21 +1,5 @@
 0.95.0	UNRELEASED
 
- UI
-
-  * Added Refresh menu option with F5 keyboard shortcut (Russ Brown)
-
- BUG FIXES
-
-  * Replace _() calls by _i18n() calls. (Vincent Ladeuil, #187283)
-  
-  * Fixed adding tags. (Javier Derderian, #228709)
-
- INTERNALS
-
-  * All i18n calls should now go through _i18n which must be imported from
-    bzrlib.plugins.gtk. This addresses the occasional collisions with '_' used
-    as an anonymous variable. (Vincent Ladeuil)
-
 
 0.94.0    2008-05-04
 

=== modified file '__init__.py'
--- __init__.py	2008-06-27 16:53:56 +0000
+++ __init__.py	2008-05-05 18:18:08 +0000
@@ -22,6 +22,7 @@
 gcommit           GTK+ commit dialog.
 gconflicts        GTK+ conflicts. 
 gdiff             Show differences in working tree in a GTK+ Window. 
+ghandle-patch     Display and optionally merge a merge directive or patch.
 ginit             Initialise a new branch.
 gmissing          GTK+ missing revisions dialog. 
 gpreferences      GTK+ preferences dialog. 
@@ -119,22 +120,21 @@
     return None
 
 
-def open_display():
-    pygtk = import_pygtk()
-    try:
-        import gtk
-    except RuntimeError, e:
-        if str(e) == "could not open display":
-            raise NoDisplayError
-    set_ui_factory()
-    return gtk
- 
-
 class GTKCommand(Command):
     """Abstract class providing GTK specific run commands."""
 
+    def open_display(self):
+        pygtk = import_pygtk()
+        try:
+            import gtk
+        except RuntimeError, e:
+            if str(e) == "could not open display":
+                raise NoDisplayError
+        set_ui_factory()
+        return gtk
+
     def run(self):
-        open_display()
+        self.open_display()
         dialog = self.get_gtk_dialog(os.path.abspath('.'))
         dialog.run()
 
@@ -168,7 +168,7 @@
 
     def run(self, location="."):
         (br, path) = branch.Branch.open_containing(location)
-        open_display()
+        self.open_display()
         from push import PushDialog
         dialog = PushDialog(br.repository, br.last_revision(), br)
         dialog.run()
@@ -193,12 +193,12 @@
             if revision is not None:
                 if len(revision) == 1:
                     tree1 = wt
-                    revision_id = revision[0].as_revision_id(tree1.branch)
+                    revision_id = revision[0].in_history(branch).rev_id
                     tree2 = branch.repository.revision_tree(revision_id)
                 elif len(revision) == 2:
-                    revision_id_0 = revision[0].as_revision_id(branch)
+                    revision_id_0 = revision[0].in_history(branch).rev_id
                     tree2 = branch.repository.revision_tree(revision_id_0)
-                    revision_id_1 = revision[1].as_revision_id(branch)
+                    revision_id_1 = revision[1].in_history(branch).rev_id
                     tree1 = branch.repository.revision_tree(revision_id_1)
             else:
                 tree1 = wt
@@ -261,7 +261,8 @@
             if revision is None:
                 revids.append(br.last_revision())
             else:
-                revids.append(revision[0].as_revision_id(br))
+                (revno, revid) = revision[0].in_history(br)
+                revids.append(revid)
         import gtk
         pp = start_viz_window(br, revids, limit)
         pp.connect("destroy", lambda w: gtk.main_quit())
@@ -286,7 +287,7 @@
     aliases = ["gblame", "gpraise"]
     
     def run(self, filename, all=False, plain=False, line='1', revision=None):
-        gtk = open_display()
+        gtk = self.open_display()
 
         try:
             line = int(line)
@@ -311,7 +312,7 @@
         if revision is not None:
             if len(revision) != 1:
                 raise BzrCommandError("Only 1 revion may be specified.")
-            revision_id = revision[0].as_revision_id(br)
+            revision_id = revision[0].in_history(br).rev_id
             tree = br.repository.revision_tree(revision_id)
         else:
             revision_id = getattr(tree, 'get_revision_id', lambda: None)()
@@ -345,7 +346,7 @@
 
     def run(self, filename=None):
         import os
-        open_display()
+        self.open_display()
         from commit import CommitDialog
         from bzrlib.errors import (BzrCommandError,
                                    NotBranchError,
@@ -386,13 +387,13 @@
 
     def run(self, path='.', revision=None):
         import os
-        gtk = open_display()
+        gtk = self.open_display()
         from status import StatusDialog
         (wt, wt_path) = workingtree.WorkingTree.open_containing(path)
         
         if revision is not None:
             try:
-                revision_id = revision[0].as_revision_id(wt.branch)
+                revision_id = revision[0].in_history(wt.branch).rev_id
             except:
                 from bzrlib.errors import BzrError
                 raise BzrError('Revision %r doesn\'t exist' % revision[0].user_spec )
@@ -410,7 +411,7 @@
     """
     def run(self):
         (br, path) = branch.Branch.open_containing(".")
-        gtk = open_display()
+        gtk = self.open_display()
         from bzrlib.plugins.gtk.mergedirective import SendMergeDirectiveDialog
         from StringIO import StringIO
         dialog = SendMergeDirectiveDialog(br)
@@ -432,7 +433,7 @@
     """
     def run(self):
         (wt, path) = workingtree.WorkingTree.open_containing('.')
-        open_display()
+        self.open_display()
         from bzrlib.plugins.gtk.conflicts import ConflictsDialog
         dialog = ConflictsDialog(wt)
         dialog.run()
@@ -443,7 +444,7 @@
 
     """
     def run(self):
-        open_display()
+        self.open_display()
         from bzrlib.plugins.gtk.preferences import PreferencesWindow
         dialog = PreferencesWindow()
         dialog.run()
@@ -487,7 +488,7 @@
 
 class cmd_ginit(GTKCommand):
     def run(self):
-        open_display()
+        self.open_display()
         from initialize import InitDialog
         dialog = InitDialog(os.path.abspath(os.path.curdir))
         dialog.run()
@@ -497,7 +498,7 @@
     def run(self):
         br = branch.Branch.open_containing('.')[0]
         
-        gtk = open_display()
+        gtk = self.open_display()
         from tags import TagsWindow
         window = TagsWindow(br)
         window.show()
@@ -534,7 +535,7 @@
 
     def run(self):
         from notify import NotifyPopupMenu
-        gtk = open_display()
+        gtk = self.open_display()
         menu = NotifyPopupMenu()
         icon = gtk.status_icon_new_from_file(icon_path("bzr-icon-64.png"))
         icon.connect('popup-menu', menu.display)
@@ -692,6 +693,42 @@
 register_command(cmd_test_gtk)
 
 
+class cmd_ghandle_patch(GTKCommand):
+    """Display a patch or merge directive, possibly merging.
+
+    This is a helper, meant to be launched from other programs like browsers
+    or email clients.  Since these programs often do not allow parameters to
+    be provided, a "handle-patch" script is included.
+    """
+
+    takes_args = ['path']
+
+    def run(self, path):
+        try:
+            from bzrlib.plugins.gtk.diff import (DiffWindow,
+                                                 MergeDirectiveWindow)
+            lines = open(path, 'rb').readlines()
+            lines = [l.replace('\r\n', '\n') for l in lines]
+            try:
+                directive = merge_directive.MergeDirective.from_lines(lines)
+            except errors.NotAMergeDirective:
+                window = DiffWindow()
+                window.set_diff_text(path, lines)
+            else:
+                window = MergeDirectiveWindow(directive, path)
+                window.set_diff_text(path, directive.patch.splitlines(True))
+            window.show()
+            gtk = self.open_display()
+            window.connect("destroy", gtk.main_quit)
+        except Exception, e:
+            from dialog import error_dialog
+            error_dialog('Error', str(e))
+            raise
+        gtk.main()
+
+
+register_command(cmd_ghandle_patch)
+
 
 import gettext
 gettext.install('olive-gtk')

=== modified file 'branchview/linegraph.py'
--- branchview/linegraph.py	2008-06-29 15:47:30 +0000
+++ branchview/linegraph.py	2008-05-04 18:16:01 +0000
@@ -12,7 +12,7 @@
 from bzrlib.revision import NULL_REVISION
 from bzrlib.tsort import merge_sort
 
-def linegraph(graph, start_revs, maxnum, broken_line_length = None,
+def linegraph(repository, start_revs, maxnum, broken_line_length = None,
               graph_data = True, mainline_only = False):
     """Produce a directed graph of a bzr repository.
 
@@ -43,6 +43,7 @@
     curved, kinked, etc.) and to pick the actual colours for each index.
     """
     
+    graph = repository.get_graph()
     graph_parents = {}
     ghosts = set()
     graph_children = {}

=== modified file 'branchview/treeview.py'
--- branchview/treeview.py	2008-06-29 15:47:30 +0000
+++ branchview/treeview.py	2008-05-05 18:16:46 +0000
@@ -3,7 +3,7 @@
 
 """
 
-__copyright__ = "Copyright © 2005 Canonical Ltd."
+__copyright__ = "Copyright  2005 Canonical Ltd."
 __author__    = "Daniel Schierbeck <daniel.schierbeck@gmail.com>"
 
 import sys
@@ -285,8 +285,8 @@
         show_graph = self.graph_column.get_visible()
 
         self.branch.lock_read()
-        (linegraphdata, index, columns_len) = linegraph(self.branch.repository.get_graph(),
-                                                        (self.start,) , # Sequence of start revisions
+        (linegraphdata, index, columns_len) = linegraph(self.branch.repository,
+                                                        self.start,
                                                         self.maxnum, 
                                                         broken_line_length,
                                                         show_graph,
@@ -339,7 +339,7 @@
         cell.set_property("width-chars", 15)
         cell.set_property("ellipsize", pango.ELLIPSIZE_END)
         self.revno_column = gtk.TreeViewColumn("Revision No")
-        self.revno_column.set_resizable(False)
+        self.revno_column.set_resizable(True)
         self.revno_column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
         self.revno_column.set_fixed_width(cell.get_size(self.treeview)[2])
         self.revno_column.pack_start(cell, expand=True)
@@ -348,9 +348,9 @@
 
         self.graph_cell = CellRendererGraph()
         self.graph_column = gtk.TreeViewColumn()
-        self.graph_column.set_resizable(False)
+        self.graph_column.set_resizable(True)
         self.graph_column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
-        self.graph_column.pack_start(self.graph_cell, expand=True)
+        self.graph_column.pack_start(self.graph_cell, expand=False)
         self.graph_column.add_attribute(self.graph_cell, "node", treemodel.NODE)
         self.graph_column.add_attribute(self.graph_cell, "tags", treemodel.TAGS)
         self.graph_column.add_attribute(self.graph_cell, "in-lines", treemodel.LAST_LINES)
@@ -361,8 +361,7 @@
         cell.set_property("width-chars", 65)
         cell.set_property("ellipsize", pango.ELLIPSIZE_END)
         self.summary_column = gtk.TreeViewColumn("Summary")
-        self.summary_column.set_resizable(False)
-        self.summary_column.set_expand(True)
+        self.summary_column.set_resizable(True)
         self.summary_column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
         self.summary_column.set_fixed_width(cell.get_size(self.treeview)[2])
         self.summary_column.pack_start(cell, expand=True)
@@ -373,9 +372,9 @@
         cell.set_property("width-chars", 15)
         cell.set_property("ellipsize", pango.ELLIPSIZE_END)
         self.committer_column = gtk.TreeViewColumn("Committer")
-        self.committer_column.set_resizable(False)
+        self.committer_column.set_resizable(True)
         self.committer_column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
-        self.committer_column.set_fixed_width(200)
+        self.committer_column.set_fixed_width(cell.get_size(self.treeview)[2])
         self.committer_column.pack_start(cell, expand=True)
         self.committer_column.add_attribute(cell, "text", treemodel.COMMITTER)
         self.treeview.append_column(self.committer_column)
@@ -385,9 +384,9 @@
         cell.set_property("ellipsize", pango.ELLIPSIZE_END)
         self.date_column = gtk.TreeViewColumn("Date")
         self.date_column.set_visible(False)
-        self.date_column.set_resizable(False)
+        self.date_column.set_resizable(True)
         self.date_column.set_sizing(gtk.TREE_VIEW_COLUMN_FIXED)
-        self.date_column.set_fixed_width(130)
+        self.date_column.set_fixed_width(cell.get_size(self.treeview)[2])
         self.date_column.pack_start(cell, expand=True)
         self.date_column.add_attribute(cell, "text", treemodel.TIMESTAMP)
         self.treeview.append_column(self.date_column)

=== modified file 'bzr-gtk.applications'
--- bzr-gtk.applications	2008-06-27 16:55:09 +0000
+++ bzr-gtk.applications	2008-04-02 18:01:18 +0000
@@ -1,5 +1,5 @@
 bzr-gtk-patch
-	command=bzr-handle-patch
+	command="bzr handle-patch"
 	name=Bazaar
 	can_open_multiple_files=false
 	expects_uris=false

=== modified file 'commit.py'
--- commit.py	2008-06-07 09:00:24 +0000
+++ commit.py	2008-05-05 18:16:46 +0000
@@ -303,9 +303,6 @@
                             gtk.gdk.CONTROL_MASK, 0, self._on_accel_next)
         self.add_accel_group(group)
 
-        # ignore the escape key (avoid closing the window)
-        self.connect_object('close', self.emit_stop_by_name, 'close')
-
     def _construct_left_pane(self):
         self._left_pane_box = gtk.VBox(homogeneous=False, spacing=5)
         self._construct_file_list()

=== modified file 'diff.py'
--- diff.py	2008-05-22 02:33:40 +0000
+++ diff.py	2008-05-05 18:16:46 +0000
@@ -328,16 +328,16 @@
         """
         # The diffs of the  selected file: a scrollable source or
         # text view
-
-    def set_diff_text_sections(self, sections):
         self.diff_view = DiffFileView()
         self.diff_view.show()
         self.pack2(self.diff_view)
-        for oldname, newname, patch in sections:
+        self.model.append(None, [ "Complete Diff", "" ])
+        self.diff_view._diffs[None] = ''.join(lines)
+        for patch in parse_patches(lines):
+            oldname = patch.oldname.split('\t')[0]
+            newname = patch.newname.split('\t')[0]
+            self.model.append(None, [oldname, newname])
             self.diff_view._diffs[newname] = str(patch)
-            if newname is None:
-                newname = ''
-            self.model.append(None, [oldname, newname])
         self.diff_view.show_diff(None)
 
     def set_diff(self, rev_tree, parent_tree):
@@ -413,7 +413,7 @@
     differences between two revisions on a branch.
     """
 
-    def __init__(self, parent=None, operations=None):
+    def __init__(self, parent=None):
         Window.__init__(self, parent)
         self.set_border_width(0)
         self.set_title("bzrk diff")
@@ -424,151 +424,82 @@
         width = int(monitor.width * 0.66)
         height = int(monitor.height * 0.66)
         self.set_default_size(width, height)
-        self.construct(operations)
-
-    def construct(self, operations):
+
+        self.construct()
+
+    def construct(self):
         """Construct the window contents."""
         self.vbox = gtk.VBox()
         self.add(self.vbox)
         self.vbox.show()
-        hbox = self._get_button_bar(operations)
+        hbox = self._get_button_bar()
         if hbox is not None:
             self.vbox.pack_start(hbox, expand=False, fill=True)
         self.diff = DiffWidget()
         self.vbox.add(self.diff)
         self.diff.show_all()
 
-    def _get_button_bar(self, operations):
+    def _get_button_bar(self):
         """Return a button bar to use.
 
         :return: None, meaning that no button bar will be used.
         """
-        if operations is None:
-            return None
+        return None
+
+    def set_diff_text(self, description, lines):
+        """Set the diff from a text.
+
+        The diff must be in unified diff format, and will be parsed to
+        determine filenames.
+        """
+        self.diff.set_diff_text(lines)
+        self.set_title(description + " - bzrk diff")
+
+    def set_diff(self, description, rev_tree, parent_tree):
+        """Set the differences showed by this window.
+
+        Compares the two trees and populates the window with the
+        differences.
+        """
+        self.diff.set_diff(rev_tree, parent_tree)
+        self.set_title(description + " - bzrk diff")
+
+    def set_file(self, file_path):
+        self.diff.set_file(file_path)
+
+
+class MergeDirectiveWindow(DiffWindow):
+
+    def __init__(self, directive, path):
+        DiffWindow.__init__(self, None)
+        self._merge_target = None
+        self.directive = directive
+        self.path = path
+
+    def _get_button_bar(self):
+        """The button bar has only the Merge button"""
+        merge_button = gtk.Button('Merge')
+        merge_button.show()
+        merge_button.set_relief(gtk.RELIEF_NONE)
+        merge_button.connect("clicked", self.perform_merge)
+
+        save_button = gtk.Button('Save')
+        save_button.show()
+        save_button.set_relief(gtk.RELIEF_NONE)
+        save_button.connect("clicked", self.perform_save)
+
         hbox = gtk.HButtonBox()
         hbox.set_layout(gtk.BUTTONBOX_START)
-        for title, method in operations:
-            merge_button = gtk.Button(title)
-            merge_button.show()
-            merge_button.set_relief(gtk.RELIEF_NONE)
-            merge_button.connect("clicked", method)
-            hbox.pack_start(merge_button, expand=False, fill=True)
+        hbox.pack_start(merge_button, expand=False, fill=True)
+        hbox.pack_start(save_button, expand=False, fill=True)
         hbox.show()
         return hbox
 
-    def _get_merge_target(self):
-        d = gtk.FileChooserDialog('Merge branch', self,
-                                  gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER,
-                                  buttons=(gtk.STOCK_OK, gtk.RESPONSE_OK,
-                                           gtk.STOCK_CANCEL,
-                                           gtk.RESPONSE_CANCEL,))
-        try:
-            result = d.run()
-            if result != gtk.RESPONSE_OK:
-                raise SelectCancelled()
-            return d.get_current_folder_uri()
-        finally:
-            d.destroy()
-
-    def _merge_successful(self):
-        # No conflicts found.
-        info_dialog(_i18n('Merge successful'),
-                    _i18n('All changes applied successfully.'))
-
-    def _conflicts(self):
-        warning_dialog(_i18n('Conflicts encountered'),
-                       _i18n('Please resolve the conflicts manually'
-                             ' before committing.'))
-
-    def _handle_error(self, e):
-        error_dialog('Error', str(e))
-
-    def _get_save_path(self, basename):
-        d = gtk.FileChooserDialog('Save As', self,
-                                  gtk.FILE_CHOOSER_ACTION_SAVE,
-                                  buttons=(gtk.STOCK_OK, gtk.RESPONSE_OK,
-                                           gtk.STOCK_CANCEL,
-                                           gtk.RESPONSE_CANCEL,))
-        d.set_current_name(basename)
-        try:
-            result = d.run()
-            if result != gtk.RESPONSE_OK:
-                raise SelectCancelled()
-            return urlutils.local_path_from_url(d.get_uri())
-        finally:
-            d.destroy()
-
-    def set_diff(self, description, rev_tree, parent_tree):
-        """Set the differences showed by this window.
-
-        Compares the two trees and populates the window with the
-        differences.
-        """
-        self.diff.set_diff(rev_tree, parent_tree)
-        self.set_title(description + " - bzrk diff")
-
-    def set_file(self, file_path):
-        self.diff.set_file(file_path)
-
-
-class DiffController(object):
-
-    def __init__(self, path, patch, window=None):
-        self.path = path
-        self.patch = patch
-        if window is None:
-            window = DiffWindow(operations=self._provide_operations())
-            self.initialize_window(window)
-        self.window = window
-
-    def initialize_window(self, window):
-        window.diff.set_diff_text_sections(self.get_diff_sections())
-        window.set_title(self.path + " - diff")
-
-    def get_diff_sections(self):
-        yield "Complete Diff", None, ''.join(self.patch)
-        for patch in parse_patches(self.patch):
-            oldname = patch.oldname.split('\t')[0]
-            newname = patch.newname.split('\t')[0]
-            yield oldname, newname, str(patch)
-
-    def perform_save(self, window):
-        try:
-            save_path = self.window._get_save_path(osutils.basename(self.path))
-        except SelectCancelled:
-            return
-        source = open(self.path, 'rb')
-        try:
-            target = open(save_path, 'wb')
-            try:
-                osutils.pumpfile(source, target)
-            finally:
-                target.close()
-        finally:
-            source.close()
-
-    def _provide_operations(self):
-        return [('Save', self.perform_save)]
-
-
-class MergeDirectiveController(DiffController):
-
-    def __init__(self, path, directive, window=None):
-        DiffController.__init__(self, path, directive.patch.splitlines(True),
-                                window)
-        self.directive = directive
-        self.merge_target = None
-
-    def _provide_operations(self):
-        return [('Merge', self.perform_merge), ('Save', self.perform_save)]
-
     def perform_merge(self, window):
-        if self.merge_target is None:
-            try:
-                self.merge_target = self.window._get_merge_target()
-            except SelectCancelled:
-                return
-        tree = workingtree.WorkingTree.open(self.merge_target)
+        try:
+            tree = self._get_merge_target()
+        except SelectCancelled:
+            return
         tree.lock_write()
         try:
             try:
@@ -579,16 +510,64 @@
                 conflict_count = merger.do_merge()
                 merger.set_pending()
                 if conflict_count == 0:
-                    self.window._merge_successful()
+                    # No conflicts found.
+                    info_dialog(_i18n('Merge successful'),
+                                _i18n('All changes applied successfully.'))
                 else:
-                    self.window._conflicts()
                     # There are conflicts to be resolved.
-                self.window.destroy()
+                    warning_dialog(_i18n('Conflicts encountered'),
+                                   _i18n('Please resolve the conflicts manually'
+                                         ' before committing.'))
+                self.destroy()
             except Exception, e:
-                self.window._handle_error(e)
+                error_dialog('Error', str(e))
         finally:
             tree.unlock()
 
+    def _get_merge_target(self):
+        if self._merge_target is not None:
+            return self._merge_target
+        d = gtk.FileChooserDialog('Merge branch', self,
+                                  gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER,
+                                  buttons=(gtk.STOCK_OK, gtk.RESPONSE_OK,
+                                           gtk.STOCK_CANCEL,
+                                           gtk.RESPONSE_CANCEL,))
+        try:
+            result = d.run()
+            if result != gtk.RESPONSE_OK:
+                raise SelectCancelled()
+            uri = d.get_current_folder_uri()
+        finally:
+            d.destroy()
+        return workingtree.WorkingTree.open(uri)
+
+    def perform_save(self, window):
+        d = gtk.FileChooserDialog('Save As', self,
+                                  gtk.FILE_CHOOSER_ACTION_SAVE,
+                                  buttons=(gtk.STOCK_OK, gtk.RESPONSE_OK,
+                                           gtk.STOCK_CANCEL,
+                                           gtk.RESPONSE_CANCEL,))
+        d.set_current_name(osutils.basename(self.path))
+        try:
+            try:
+                result = d.run()
+                if result != gtk.RESPONSE_OK:
+                    raise SelectCancelled()
+                uri = d.get_uri()
+            finally:
+                d.destroy()
+        except SelectCancelled:
+            return
+        source = open(self.path, 'rb')
+        try:
+            target = open(urlutils.local_path_from_url(uri), 'wb')
+            try:
+                target.write(source.read())
+            finally:
+                target.close()
+        finally:
+            source.close()
+
 
 def iter_changes_to_status(source, target):
     """Determine the differences between trees.

=== renamed file 'bzr-handle-patch' => 'handle-patch'
--- bzr-handle-patch	2008-06-27 16:53:56 +0000
+++ handle-patch	2008-02-23 06:39:14 +0000
@@ -1,39 +1,2 @@
-#!/usr/bin/python
-
-from bzrlib import errors, merge_directive
-from bzrlib.plugin import load_plugins
-from bzrlib.plugins.gtk import open_display
-load_plugins()
-
-import sys
-
-if len(sys.argv) < 2:
-	print "Usage: handle-patch <path>"
-	sys.exit(1)
-
-
-path = sys.argv[1]
-
-try:
-	from bzrlib.plugins.gtk.diff import (DiffController,
-										 MergeDirectiveController)
-	if path == '-':
-		lines = sys.stdin.readlines()
-	else:
-		lines = open(path, 'rb').readlines()
-	lines = [l.replace('\r\n', '\n') for l in lines]
-	try:
-		directive = merge_directive.MergeDirective.from_lines(lines)
-	except errors.NotAMergeDirective:
-		controller = DiffController(path, lines)
-	else:
-		controller = MergeDirectiveController(path, directive)
-	window = controller.window
-	window.show()
-	gtk = open_display()
-	window.connect("destroy", gtk.main_quit)
-except Exception, e:
-	from dialog import error_dialog
-	error_dialog('Error', str(e))
-	raise
-gtk.main()
+#!/bin/sh
+/home/abentley/bin/bzr ghandle-patch "$@"

=== removed file 'olive-gtk.1'
--- olive-gtk.1	2008-05-01 12:55:33 +0000
+++ olive-gtk.1	1970-01-01 00:00:00 +0000
@@ -1,15 +0,0 @@
-.TH OLIVE-GTK 1 "April 24, 2007"
-.SH NAME
-olive-gtk \- GTK+ frontend for Bazaar
-.SH SYNOPSIS
-.B olive-gtk
-.SH DESCRIPTION
-Olive aims to be a full-featured graphical frontend for the Bazaar (bzr)
-source code management tool.
-.SH SEE ALSO
-.BR bzr (1).
-.SH AUTHOR
-\fBolive-gtk\fP was written by Szilveszter Farkas <szilveszter.farkas@gmail.com>
-.PP
-This manual page was written by Chris Lamb <chris@chris-lamb.co.uk>,
-for the Debian project (but may be used by others).

=== modified file 'olive-gtk.desktop'
--- olive-gtk.desktop	2008-06-03 01:43:08 +0000
+++ olive-gtk.desktop	2008-05-01 13:00:15 +0000
@@ -9,4 +9,4 @@
 Comment[pl]=Graficzny interfejs dla systemu kontroli wersji Bazaar
 Icon=olive-gtk.png
 Exec=olive-gtk
-Categories=Application;Development;RevisionControl;GTK;GNOME;
+Categories=Application;Development;RevisionControl;

=== modified file 'olive/__init__.py'
--- olive/__init__.py	2008-06-23 08:05:19 +0000
+++ olive/__init__.py	2008-05-05 18:16:46 +0000
@@ -446,7 +446,7 @@
     @show_bzr_error
     def on_entry_history_revno_key_press_event(self, widget, event):
         """ Key pressed handler for the history entry. """
-        if event.keyval == gtk.gdk.keyval_from_name('Return') or event.keyval == gtk.gdk.keyval_from_name('KP_Enter'):
+        if event.keyval == 65293:
             # Return was hit, so we have to load that specific revision
             # Emulate being remote, so inventory should be used
             path = self.get_path()
@@ -461,7 +461,7 @@
     
     def on_entry_location_key_press_event(self, widget, event):
         """ Key pressed handler for the location entry. """
-        if event.keyval == gtk.gdk.keyval_from_name('Return') or event.keyval == gtk.gdk.keyval_from_name('KP_Enter'):
+        if event.keyval == 65293:
             # Return was hit, so we have to jump
             self.on_button_location_jump_clicked(widget)
     

=== modified file 'revisionview.py'
--- revisionview.py	2008-06-24 10:34:38 +0000
+++ revisionview.py	2008-05-04 18:28:46 +0000
@@ -20,7 +20,7 @@
 import gtk
 import pango
 import gobject
-import webbrowser
+import subprocess
 
 from bzrlib.plugins.gtk import icon_path
 from bzrlib.osutils import format_date
@@ -38,12 +38,8 @@
 PAGE_SIGNATURE = 2
 PAGE_BUGS = 3
 
-
 def _open_link(widget, uri):
-    for cmd in ['sensible-browser', 'xdg-open']:
-        if webbrowser._iscommand(cmd):
-            webbrowser._tryorder.insert(0, '%s "%%s"' % cmd)
-    webbrowser.open(uri)
+    subprocess.Popen(['sensible-browser', uri], close_fds=True)
 
 gtk.link_button_set_uri_hook(_open_link)
 

=== modified file 'seahorse.py'
--- seahorse.py	2008-06-20 03:33:17 +0000
+++ seahorse.py	2008-05-01 21:49:50 +0000
@@ -29,28 +29,15 @@
 KEY_TYPE_SSH = 'ssh'
 
 try:
-    bus = dbus.SessionBus()
-except dbus.exceptions.DBusException, e:
-    get_name = getattr(e, 'get_dbus_name', None)
-    if get_name is not None:
-        name = get_name()
-    else:
-        name = getattr(e, '_dbus_error_name', None)
-    # DBus sometimes fails like this, just treat it as if seahorse is not
-    # available rather than crashing.
-    if name == "org.freedesktop.DBus.Error.Spawn.ExecFailed":
-        raise ImportError
-    else:
-        raise
-
-if hasattr(bus, 'list_activatable_names'):
-    bus_names = bus.list_activatable_names()
-else:
-    bus_object = bus.get_object('org.freedesktop.DBus', '/org/freedesktop/DBus')
-    bus_names = bus_object.ListNames(dbus_interface='org.freedesktop.DBus')
-
-if BUS_NAME not in bus_names:
-    raise ImportError
+    dbus.validate_bus_name(BUS_NAME)
+except ValueError:
+    # Seahorse isn't installed
+    raise ImportError
+except AttributeError:
+    # Outdated version of DBus that doesn't have validate_bus_name
+    raise ImportError
+
+bus = dbus.SessionBus()
 
 crypto = dbus.Interface(bus.get_object(BUS_NAME, CRYPTO_PATH), 
                         CRYPTO_INTERFACE)

=== modified file 'setup.py'
--- setup.py	2008-06-27 16:53:56 +0000
+++ setup.py	2008-05-04 20:23:56 +0000
@@ -96,7 +96,7 @@
     maintainer_email = "jelmer@samba.org",
     description = "GTK+ Frontends for various Bazaar commands",
     license = "GNU GPL v2 or later",
-    scripts=['olive-gtk', 'bzr-handle-patch'],
+    scripts=['olive-gtk'],
     package_dir = {
         "bzrlib.plugins.gtk": ".",
         "bzrlib.plugins.gtk.viz": "viz", 

=== modified file 'tags.py'
--- tags.py	2008-05-23 13:14:58 +0000
+++ tags.py	2008-05-05 18:16:46 +0000
@@ -327,7 +327,7 @@
             if self._hbox_revid.get_revision_id() is None:
                 self._revid = self._branch.last_revision()
             else:
-                self._revid = self._hbox_revid.get_revision_id()
+                self._revid = self.hbox_revid.get_revision_id()
             
         self.tagname = self._entry_name.get_text()
         

=== modified file 'tests/test_commit.py'
--- tests/test_commit.py	2008-06-10 15:25:47 +0000
+++ tests/test_commit.py	2008-05-04 13:11:26 +0000
@@ -81,8 +81,8 @@
         rev_id1 = tree.commit('one')
         tree2 = tree.bzrdir.sprout('tree2').open_workingtree()
         rev_id2 = tree2.commit('two')
+        rev_id3 = tree2.commit('three')
         tree3 = tree2.bzrdir.sprout('tree3').open_workingtree()
-        rev_id3 = tree2.commit('three')
         rev_id4 = tree3.commit('four')
         rev_id5 = tree3.commit('five')
         tree.merge_from_branch(tree2.branch)
@@ -985,7 +985,8 @@
                          ], bencode.bdecode(file_info))
 
     def test_commit_unicode_messages(self):
-        self.requireFeature(tests.UnicodeFilenameFeature)
+        from bzrlib.tests.test_diff import UnicodeFilename
+        self.requireFeature(UnicodeFilename)
 
         tree = self.make_branch_and_tree('tree')
         tree.branch.get_config().set_user_option('per_file_commits', 'true')

=== modified file 'tests/test_diff.py'
--- tests/test_diff.py	2008-06-09 15:59:13 +0000
+++ tests/test_diff.py	2008-03-11 13:18:28 +0000
@@ -18,33 +18,10 @@
 from cStringIO import StringIO
 import os
 
-from bzrlib import errors, tests
-from bzrlib.merge_directive import MergeDirective2
-
-from bzrlib.plugins.gtk.diff import (
-    DiffController,
-    DiffView,
-    iter_changes_to_status,
-    MergeDirectiveController,
-    )
-eg_diff = """\
-=== modified file 'tests/test_diff.py'
---- tests/test_diff.py	2008-03-11 13:18:28 +0000
-+++ tests/test_diff.py	2008-05-08 22:44:02 +0000
-@@ -20,7 +20,11 @@
- 
- from bzrlib import tests
- 
--from bzrlib.plugins.gtk.diff import DiffView, iter_changes_to_status
-+from bzrlib.plugins.gtk.diff import (
-+    DiffController,
-+    DiffView,
-+    iter_changes_to_status,
-+    )
- 
- 
- class TestDiffViewSimple(tests.TestCase):
-"""
+from bzrlib import tests
+
+from bzrlib.plugins.gtk.diff import DiffView, iter_changes_to_status
+
 
 class TestDiffViewSimple(tests.TestCase):
 
@@ -69,7 +46,8 @@
 class TestDiffView(tests.TestCaseWithTransport):
 
     def test_unicode(self):
-        self.requireFeature(tests.UnicodeFilenameFeature)
+        from bzrlib.tests.test_diff import UnicodeFilename
+        self.requireFeature(UnicodeFilename)
 
         tree = self.make_branch_and_tree('tree')
         self.build_tree([u'tree/\u03a9'])
@@ -91,122 +69,6 @@
             )
 
 
-class MockDiffWidget(object):
-
-    def set_diff_text_sections(self, sections):
-        self.sections = list(sections)
-
-
-class MockWindow(object):
-    def __init__(self):
-        self.diff = MockDiffWidget()
-        self.merge_successful = False
-
-    def set_title(self, title):
-        self.title = title
-
-    def _get_save_path(self, basename):
-        return 'save-path'
-
-    def _get_merge_target(self):
-        return 'this'
-
-    def destroy(self):
-        pass
-
-    def _merge_successful(self):
-        self.merge_successful = True
-
-    def _conflicts(self):
-        self.conflicts = True
-
-    def _handle_error(self, e):
-        self.handled_error = e
-
-
-class TestDiffController(tests.TestCaseWithTransport):
-
-    def get_controller(self):
-        window = MockWindow()
-        return DiffController('load-path', eg_diff.splitlines(True), window)
-
-    def test_get_diff_sections(self):
-        controller = self.get_controller()
-        controller = DiffController('.', eg_diff.splitlines(True),
-                                    controller.window)
-        sections = list(controller.get_diff_sections())
-        self.assertEqual('Complete Diff', sections[0][0])
-        self.assertIs(None, sections[0][1])
-        self.assertEqual(eg_diff, sections[0][2])
-
-        self.assertEqual('tests/test_diff.py', sections[1][0])
-        self.assertEqual('tests/test_diff.py', sections[1][1])
-        self.assertEqual(''.join(eg_diff.splitlines(True)[1:]),
-                         sections[1][2])
-
-    def test_initialize_window(self):
-        controller = self.get_controller()
-        controller.initialize_window(controller.window)
-        self.assertEqual(2, len(controller.window.diff.sections))
-        self.assertEqual('load-path - diff', controller.window.title)
-
-    def test_perform_save(self):
-        self.build_tree_contents([('load-path', 'foo')])
-        controller = self.get_controller()
-        controller.perform_save(None)
-        self.assertFileEqual('foo', 'save-path')
-
-
-class TestMergeDirectiveController(tests.TestCaseWithTransport):
-
-    def make_this_other_directive(self):
-        this = self.make_branch_and_tree('this')
-        this.commit('first commit')
-        other = this.bzrdir.sprout('other').open_workingtree()
-        self.build_tree_contents([('other/foo', 'bar')])
-        other.add('foo')
-        other.commit('second commit')
-        other.lock_write()
-        try:
-            directive = MergeDirective2.from_objects(other.branch.repository,
-                                                     other.last_revision(), 0,
-                                                     0, 'this')
-        finally:
-            other.unlock()
-        return this, other, directive
-
-    def make_merged_window(self, directive):
-        window = MockWindow()
-        controller = MergeDirectiveController('directive', directive, window)
-        controller.perform_merge(window)
-        return window
-
-    def test_perform_merge_success(self):
-        this, other, directive = self.make_this_other_directive()
-        window = self.make_merged_window(directive)
-        self.assertTrue(window.merge_successful)
-        self.assertEqual(other.last_revision(), this.get_parent_ids()[1])
-        self.assertFileEqual('bar', 'this/foo')
-
-    def test_perform_merge_conflicts(self):
-        this, other, directive = self.make_this_other_directive()
-        self.build_tree_contents([('this/foo', 'bar')])
-        this.add('foo')
-        this.commit('message')
-        window = self.make_merged_window(directive)
-        self.assertFalse(window.merge_successful)
-        self.assertTrue(window.conflicts)
-        self.assertEqual(other.last_revision(), this.get_parent_ids()[1])
-        self.assertFileEqual('bar', 'this/foo')
-
-    def test_perform_merge_uncommitted_changes(self):
-        this, other, directive = self.make_this_other_directive()
-        self.build_tree_contents([('this/foo', 'bar')])
-        this.add('foo')
-        window = self.make_merged_window(directive)
-        self.assertIsInstance(window.handled_error, errors.UncommittedChanges)
-
-
 class Test_IterChangesToStatus(tests.TestCaseWithTransport):
 
     def assertStatusEqual(self, expected, tree):

=== modified file 'ui.py'
--- ui.py	2008-06-20 03:36:30 +0000
+++ ui.py	2008-03-20 16:06:23 +0000
@@ -58,7 +58,7 @@
     def update(self, msg=None, current=None, total=None):
         if msg is not None:
             self.set_text(msg)
-        if None not in (current, total) and total > 0:
+        if None not in (current, total):
             self.set_fraction(1.0 * current / total)
         while gtk.events_pending():
             gtk.main_iteration()
@@ -86,8 +86,6 @@
 
     def remove(self, pb):
         self.vbox.remove(pb)
-        if len(self.vbox.get_children()) == 0: # If there is nothing to show, don't leave a ghost window here
-             self.destroy()
 
 
 class PasswordDialog(gtk.Dialog):

=== modified file 'viz/branchwin.py'
--- viz/branchwin.py	2008-06-06 17:46:26 +0000
+++ viz/branchwin.py	2008-04-25 20:27:21 +0000
@@ -66,7 +66,6 @@
 
         gtk.accel_map_add_entry("<viz>/Go/Next Revision", gtk.keysyms.Up, gtk.gdk.MOD1_MASK)
         gtk.accel_map_add_entry("<viz>/Go/Previous Revision", gtk.keysyms.Down, gtk.gdk.MOD1_MASK)
-        gtk.accel_map_add_entry("<viz>/View/Refresh", gtk.keysyms.F5, 0)
 
         self.accel_group = gtk.AccelGroup()
         self.add_accel_group(self.accel_group)
@@ -85,12 +84,6 @@
         self.next_rev_action.connect("activate", self._fwd_clicked_cb)
         self.next_rev_action.connect_accelerator()
 
-        self.refresh_action = gtk.Action("refresh", "_Refresh", "Refresh view", gtk.STOCK_REFRESH)
-        self.refresh_action.set_accel_path("<viz>/View/Refresh")
-        self.refresh_action.set_accel_group(self.accel_group)
-        self.refresh_action.connect("activate", self._refresh_clicked)
-        self.refresh_action.connect_accelerator()
-
         self.construct()
 
     def set_revision(self, revid):
@@ -151,12 +144,6 @@
         view_menuitem = gtk.MenuItem("_View")
         view_menuitem.set_submenu(view_menu)
 
-        view_menu_refresh = self.refresh_action.create_menu_item()
-        view_menu_refresh.connect('activate', self._refresh_clicked)
-
-        view_menu.add(view_menu_refresh)
-        view_menu.add(gtk.SeparatorMenuItem())
-
         view_menu_toolbar = gtk.CheckMenuItem("Show Toolbar")
         view_menu_toolbar.set_active(True)
         view_menu_toolbar.connect('toggled', self._toolbar_visibility_changed)

